.slide-content {
    min-width: 70%;
}

.highlight {
    font-family: monospace;
    font-weight: bold;
    border: 2px solid rgb(138, 138, 138);
    border-radius: 10px;
    padding: 20px;
}

.highlight>pre {
    margin: 0px;
}

@media (prefers-color-scheme: light) {

    /* Syntax highlighting, derived from VS Code "Quiet Light" theme */
    :root {
        --hl-comment: rgb(116, 116, 116);
        --hl-doc: rgb(87, 151, 61);
        --hl-keyword: rgb(122, 62, 157);
        --hl-var: rgb(122, 62, 157);
        --hl-func: rgb(170, 55, 49);
        --hl-type: rgb(122, 62, 157);
        --hl-string: rgb(87, 151, 61);
    }
}

@media (prefers-color-scheme: dark) {

    /* Syntax highlighting, derived from VS Code "Synthwave '84" theme */
    :root {
        --hl-comment: rgb(128, 135, 184);
        --hl-doc: rgb(128, 135, 184);
        --hl-keyword: rgb(254, 222, 93);
        --hl-var: rgb(237, 119, 205);
        --hl-func: rgb(3, 237, 249);
        --hl-type: rgb(214, 62, 75);
        --hl-string: rgb(255, 139, 57);
    }
}
