body {
    font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
    display: flex;
    flex-direction: column;
    justify-content: center;
    align-items: center;
    font-size: 1.7rem;
}

h1 {
    font-size: 5rem;
    text-align: center;
}

@media (prefers-color-scheme: dark) {
    html {
        background-color: rgb(27, 27, 27);
        color: white;
    }
}
