html {
    background: rgb(27, 27, 27) url('/theme/bliss.jpg');
    background-size: cover;
    min-height: 100vh;
    overflow-x: hidden;
}

body {
    font-family: Tahoma, Verdana, Segoe, sans-serif;
    font-size: 1.7rem;
    margin: 0;
}

h1 {
    font-size: 5rem;
    text-align: center;
}

.highlight {
    font-family: Consolas, Hack, monospace;
}
