.picker-box {
    min-width: 70%;
}

.picker-item a {
    text-decoration: none;
}
.picker-item a:hover {
    text-decoration: underline;
}

@media (prefers-color-scheme: light) {
    .picker-item a {
        color: black;
    }
}

@media (prefers-color-scheme: dark) {
    .picker-item a {
        color: white;
    }
}
